==> qt-creator-opensource-src-3.3.1.zip: qt-creator-opensource-src-3.3.1/src/plugins/diffeditor/diffeditormanager.h <==
/****************************************************************************
**
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company.  For licensing terms and
** conditions see http://www.qt.io/terms-conditions.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, The Qt Company gives you certain additional
** rights.  These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef DIFFEDITORMANAGER_H
#define DIFFEDITORMANAGER_H

#include "diffeditor_global.h"

#include <coreplugin/editormanager/ieditor.h>
#include <coreplugin/idocument.h>

#include <QMap>

namespace DiffEditor {

class DiffEditorDocument;

class DIFFEDITOR_EXPORT DiffEditorManager : public QObject
{
    Q_OBJECT
public:
    explicit DiffEditorManager(QObject *parent);
    virtual ~DiffEditorManager();

    static DiffEditorManager *instance();

    static DiffEditorDocument *find(const QString &documentId);
    static DiffEditorDocument *findOrCreate(const QString &documentId, const QString &displayName);
    static void removeDocument(DiffEditorDocument *document);

private slots:
    void slotEditorsClosed(const QList<Core::IEditor *> &editors);

private:
    QMap<QString, DiffEditorDocument *> idToDocument;
    QMap<DiffEditorDocument *, QString> documentToId;
};

} // namespace DiffEditor

#endif // DIFFEDITORMANAGER_H

==> qt-creator-opensource-src-3.4.0.zip: qt-creator-opensource-src-3.4.0/src/plugins/diffeditor/diffeditormanager.h <==
/****************************************************************************
**
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company.  For licensing terms and
** conditions see http://www.qt.io/terms-conditions.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, The Qt Company gives you certain additional
** rights.  These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef DIFFEDITORMANAGER_H
#define DIFFEDITORMANAGER_H

#include "diffeditor_global.h"

#include <QMap>
#include <QObject>

namespace Core {
class IDocument;
class IEditor;
}

namespace DiffEditor {

class DiffEditorController;

namespace Internal { class DiffEditorDocument; }

class DIFFEDITOR_EXPORT DiffEditorManager : public QObject
{
    Q_OBJECT
public:
    explicit DiffEditorManager(QObject *parent);
    virtual ~DiffEditorManager();

    static Core::IDocument *findOrCreate(const QString &vcsId, const QString &displayName);
    static DiffEditorController *controller(Core::IDocument *document);

private:
    static Core::IDocument *find(const QString &vcsId);
    static void removeDocument(Core::IDocument *document);

    QMap<QString, Internal::DiffEditorDocument *> m_idToDocument;

    friend class Internal::DiffEditorDocument;
};

} // namespace DiffEditor

#endif // DIFFEDITORMANAGER_H
